function gforder = orderGratingFlicker(Nbase, oseed, Npresent)
% orderGratingFlicker - Generates a random order of grating stimuli for a fixed or running sequence
%
% Syntax:  gforder = orderGratingFlicker(Nbase, oseed, Npresent)
%
% Inputs:
%    Nbase - number of different gratings
%    oseed - seed for the random number generator, used to generate a random sequence of values
%    Npresent - number of grating stimuli that were presented
%
% Outputs:
%    gforder - [1, Npresent] random order of grating stimuli
%
% Example:
%    currorder = orderGratingFlicker(Ngratings, seed, Npresent)
%    where seed is either the seed for the frozen sequence, 
%    or the seed for the running sequence

% Other m-files required: ran1
% Subfunctions: none
% MAT-files required: none

rnd_val = ran1(oseed, Npresent);
gforder = floor(Nbase*rnd_val) + 1;


end

